`awsmate` is a companion for your AWS Python developments.


## Installation

* Command line: `pip3 install awsmate`
* See the [PyPI page](https://pypi.org/project/awsmate/ "PyPI page of awsmate")


## Documentation

* The complete documentation is available [at ReadTheDocs](https://awsmate.readthedocs.io/ "awsmate documentation").
* Documentation status: [![Documentation status](https://readthedocs.org/projects/awsmate/badge/?version=latest)](https://awsmate.readthedocs.io/en/latest/?badge=latest)

## Testing

* Testing tool: `pytest`
* Command line: `pytest [-v|-vv]`. Should be run from the base directory of the repository.
* Tests files location:

        awsmate
            |___tests
                    |
                    |___unit
                    |
                    |___integration

* master branch tests status: ![master branch tests status](https://github.com/shlublu/awsmate/actions/workflows/tests.yaml/badge.svg?branch=master)

## License

This project is licensed under the EUROPEAN UNION PUBLIC LICENCE (EUPL) v. 1.2, which is compatible with the vast majority of open source licences.

* [View all translations](https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12 "Translations of the EUPL-1.2")
* [Compatibility matrix](https://joinup.ec.europa.eu/collection/eupl/matrix-eupl-compatible-open-source-licences "Compatibility matrix of the EUPL-1.2")
